@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Prereqs::From::cpmfile v0.0.2 {
+package Dist::Zilla::Plugin::Prereqs::From::cpmfile v0.0.3 {
     use 5.34.0;
     use Moose;
 
@@ -29,7 +29,7 @@ package Dist::Zilla::Plugin::Prereqs::From::cpmfile v0.0.2 {
 
     sub metadata ($self, @) {
         my $features = $self->cpmfile->features;
-        return +{} if !$features->%*;
+        return +{} if !$features;
 
         my $optional_features = {};
         for my $name (sort keys $features->%*) {
